class ExtractClass:
    def getDateItems(self):
        return self.getByFilter('type', 'date')

    def getDistanceItems(self):
        return self.getByFilter('type', 'distance')

    def getDurationItems(self):
        return self.getByFilter('type', 'duration')

    def getElectricPowerItems(self):
        return self.getByFilter('type', 'electric power')

    def getHexColorItems(self):
        return self.getByFilter('type', 'hex color')

    def getIntervalItems(self):
        return self.getByFilter('type', 'interval')

    def getIpItems(self):
        return self.getByFilter('type', 'ip')

    def getIpv6Items(self):
        return self.getByFilter('type', 'ipv6')

    def getLightIntensityItems(self):
        return self.getByFilter('type', 'light intensity')

    def getMailItems(self):
        return self.getByFilter('type', 'mail')

    def getMassItems(self):
        return self.getByFilter('type', 'mass')

    def getMassByVolumeItems(self):
        return self.getByFilter('type', 'mass by volume')

    def getMolItems(self):
        return self.getByFilter('type', 'mol')

    def getMoneyItems(self):
        return self.getByFilter('type', 'money')

    def getOrdinalItems(self):
        return self.getByFilter('type', 'ordinal')

    def getPercentItems(self):
        return self.getByFilter('type', 'percent')

    def getPhoneItems(self):
        return self.getByFilter('type', 'phone')

    def getPressureItems(self):
        return self.getByFilter('type', 'pressure')

    def getSetItems(self):
        return self.getByFilter('type', 'set')

    def getSpeedItems(self):
        return self.getByFilter('type', 'speed')

    def getStrengthItems(self):
        return self.getByFilter('type', 'strength')

    def getSurfaceItems(self):
        return self.getByFilter('type', 'surface')

    def getSurfaceTensionItems(self):
        return self.getByFilter('type', 'surface tension')

    def getTemperatureItems(self):
        return self.getByFilter('type', 'temperature')

    def getTimeItems(self):
        return self.getByFilter('type', 'time')

    def getUrlItems(self):
        return self.getByFilter('type', 'url')

    def getVoltageItems(self):
        return self.getByFilter('type', 'voltage')

    def getVolumeItems(self):
        return self.getByFilter('type', 'volume')

    def getHappinessItems(self):
        return self.getByFilter('type', 'happiness')

    def getSadnessItems(self):
        return self.getByFilter('type', 'sadness')

    def getFearItems(self):
        return self.getByFilter('type', 'fear')

    def getDisgustItems(self):
        return self.getByFilter('type', 'disgust')

    def getAngerItems(self):
        return self.getByFilter('type', 'anger')

    def getSurpriseItems(self):
        return self.getByFilter('type', 'surprise')

    def getJudgementItems(self):
        return self.getByFilter('type', 'judgement')
